# django-olympus

Collect data from django models into ElasticSearch

## TODO

- integration tests: spin up a docker with ES and run a collector from the test app
- support different elasticsearch version (and libs) using option.extra.installs?
- DOCS!
